package com.ruoyi.learn.service;

import java.util.List;
import com.ruoyi.learn.domain.LearnKnowledgeCourse;

/**
 * 同步知识点树Service接口
 * 
 * @author ruoyi
 * @date 2025-11-04
 */
public interface ILearnKnowledgeCourseService 
{
    /**
     * 查询同步知识点树
     * 
     * @param id 同步知识点树主键
     * @return 同步知识点树
     */
    public LearnKnowledgeCourse selectLearnKnowledgeCourseById(Long id);

    /**
     * 查询同步知识点树列表
     * 
     * @param learnKnowledgeCourse 同步知识点树
     * @return 同步知识点树集合
     */
    public List<LearnKnowledgeCourse> selectLearnKnowledgeCourseList(LearnKnowledgeCourse learnKnowledgeCourse);

    /**
     * 新增同步知识点树
     * 
     * @param learnKnowledgeCourse 同步知识点树
     * @return 结果
     */
    public int insertLearnKnowledgeCourse(LearnKnowledgeCourse learnKnowledgeCourse);

    /**
     * 修改同步知识点树
     * 
     * @param learnKnowledgeCourse 同步知识点树
     * @return 结果
     */
    public int updateLearnKnowledgeCourse(LearnKnowledgeCourse learnKnowledgeCourse);

    /**
     * 批量删除同步知识点树
     * 
     * @param ids 需要删除的同步知识点树主键集合
     * @return 结果
     */
    public int deleteLearnKnowledgeCourseByIds(Long[] ids);

    /**
     * 删除同步知识点树信息
     * 
     * @param id 同步知识点树主键
     * @return 结果
     */
    public int deleteLearnKnowledgeCourseById(Long id);
}
